@@ -7,8 +7,6 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
-#ifndef lint
-#endif
 /*******************************************************************\
 * 								    *
 * 	Information Technology Center				    *
@@ -23,8 +21,14 @@
 	IO Manager routines & server process for VICE server.
 */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/lwp/iomgr.c,v 1.7 2001/08/08 00:03:52 shadow Exp $");
+
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #include <malloc.h>
@@ -160,6 +164,7 @@ static struct timeval iomgr_badtv;
 static PROCESS iomgr_badpid;
 static void SignalIO(int fds, fd_set *rfds, fd_set *wfds, fd_set *efs,
 		    int code);
+static void SignalTimeout(int code, struct timeval *timeout);
 
 #ifdef AFS_DJGPP_ENV
 /* handle Netbios NCB completion */
@@ -217,7 +222,7 @@ static struct IoRequest *NewRequest()
 {
     struct IoRequest *request;
 
-    if (request=iorFreeList)
+    if ((request=iorFreeList))
 	iorFreeList = (struct IoRequest *) (request->result);
     else request = (struct IoRequest *) malloc(sizeof(struct IoRequest));
 
@@ -239,7 +244,7 @@ static struct IoRequest *NewRequest()
 #else
 #define FDS_P_POS (sizeof(int)*8)
 #define INTS_PER_FDS(x) (((x)+(FDS_P_POS-1)) / FDS_P_POS)
-#define FD_N_ZERO(nfds, x) bzero((char*)(x), (INTS_PER_FDS(nfds))*sizeof(int))
+#define FD_N_ZERO(nfds, x) memset((char*)(x), 0, (INTS_PER_FDS(nfds))*sizeof(int))
 #endif
 
 #if defined(AFS_LINUX22_ENV) && (__GLIBC_MINOR__ > 0)
@@ -401,9 +406,6 @@ static int IOMGR(void *dummy)
 	struct TM_Elem *earliest;
 	struct timeval timeout, junk;
 	bool woke_someone;
-#ifndef AFS_NT40_ENV
-	int fds;
-#endif
 
 	FD_ZERO(&IOMGR_readfds);
 	FD_ZERO(&IOMGR_writefds);
